@@ -1,12 +1,16 @@
-#!/usr/bin/env wish
+#!/usr/bin/env tclsh
 
 # Script to install taglog - this is under development.
 # Inoke as wish install.tcl (for Unix) or by clicking on the install icon
 #  (for Windows)
 
+package require Tk
+
 proc do_install {} {
 global bindir taglogbin libfiles libdir docdir helpfiles msgfiles mandir man1files man3files removeold activitiesfile
 global rootdir tcl_platform
+global activitiesdir
+global userinstall
 
 # Make the directories follow the libdir in windows if they were changed
 # by the user.
@@ -16,6 +20,7 @@ if {$tcl_platform(platform) == "windows" } {
  set docdir $libdir
  set mandir $libdir
  set rootdir $libdir
+ set activitiesdir $libdir
 }
 
 #
@@ -25,6 +30,10 @@ if { ! [ file isdirectory $bindir ] } {
 
 file copy -force taglog $taglogbin
 #puts "Installed taglog into $taglogbin"
+if { $tcl_platform(platform) == "unix" } {
+    # make it executable by user and group
+	file attributes $taglogbin -permissions ug+rx
+}
 
 if { ! [ file isdirectory $libdir ] } {
   file mkdir $libdir
@@ -73,7 +82,10 @@ file copy -force $docfile $docdir
  }
 }
 
-file copy -force $activitiesfile  $rootdir
+if { ! [file isdirectory $activitiesdir]} {
+  file mkdir $activitiesdir
+  }
+file copy -force $activitiesfile  $activitiesdir/$activitiesfile
 
 }
 
@@ -81,41 +93,54 @@ file copy -force $activitiesfile  $rootdir
 exit
 }
 
+proc choose_dir {var label} {
+    upvar #0 $var dir
+    set dir [tk_chooseDirectory -title $label -parent .]
+}
+
+proc directory_chooser {path label var} {
+    frame $path
+    label $path.l -text $label -width 30 -anchor w
+    entry $path.e -textvariable $var -width 30
+    button $path.c -text "..." -command [list choose_dir $var $label]
+    grid $path.l $path.e $path.c -sticky w
+    grid columnconfigure $path 1 -weight 1
+    return $path
+}
+
+proc choose_file {var label} {
+    upvar #0 $var file
+    set file [tk_getOpenFile -title $label -parent .]
+}
+
+proc file_chooser {path label var} {
+    frame $path
+    label $path.l -text $label -anchor w -width 30
+    entry $path.e -textvariable $var -width 30
+    button $path.c -text "..." -command [list choose_file $var $label]
+    grid $path.l $path.e $path.c -sticky w
+    grid columnconfigure $path 1 -weight 1
+    return $path
+}
+
 proc setup_display {} {
-global bindir taglogbin libfiles libdir docdir removeold
+global bindir taglogbin libfiles libdir docdir removeold userinstall
 
 wm title . "Install Taglog"
 
+set bin [directory_chooser .bindir "Binary Directory" ::bindir]
+set tagbin [file_chooser .taglogbin "Taglog executable" ::taglogbin]
+set lib [directory_chooser .libdir "Library Directory" ::libdir]
+set man [directory_chooser .mandir "Manpage dir" ::mandir]
+set doc [directory_chooser .docdir "Documentation Directory" ::docdir]
+set root [directory_chooser .datadir "Data Directory" ::rootdir]
 
-frame .bindir
-label .bindir.l -text "Binary Directory"
-entry .bindir.e -textvariable bindir -width 20
-pack .bindir.l .bindir.e -side left -in .bindir
-pack .bindir
-
-frame .taglogbin
-label .taglogbin.l -text "Taglog executable"
-entry .taglogbin.e -textvariable taglogbin -width 30
-pack .taglogbin.l .taglogbin.e -side left -in .taglogbin
-pack .taglogbin
-
-frame .libdir
-label .libdir.l -text "Library Directory"
-entry .libdir.e -textvariable  libdir -width 30
-pack .libdir.l .libdir.e -side left -in .libdir
-pack .libdir
-
-frame .docdir
-label .docdir.l -text "Documentation Directory"
-entry .docdir.e -textvariable docdir -width 30
-pack .docdir.l .docdir.e -side left -in .docdir
-pack .docdir
-
-frame .rootdir
-label .rootdir.l -text "Data Directory"
-entry .rootdir.e -textvariable rootdir -width 30
-pack .rootdir.l .rootdir.e -side left -in .rootdir
-pack .rootdir
+grid $bin -sticky w
+grid $tagbin -sticky w
+grid $lib -sticky w
+grid $man -sticky w
+grid $doc -sticky w
+grid $root -sticky w
 
 # For the case where the library files have moved we want to issue a
 # warning (and remove the old files
@@ -134,18 +159,18 @@ if {[tk_messageBox -icon warning -title "Library has moved" -message \
 }
 }
 
-
 frame .bot
 button .bot.ok -text OK -command do_install
 button .bot.cancel -text Cancel -command exit
-pack .bot.ok .bot.cancel -in .bot -side left
-pack .bot
+grid .bot.ok .bot.cancel -sticky w -padx 3
+grid .bot -sticky w
 
 tkwait window .
 }
 
 
 global bindir taglogbin libfiles libdir argv docdir helpfiles destdir mandir removeold
+global activitiesdir
 
 set quiet 0
 set debian 0
@@ -153,27 +178,39 @@ set system 0
 set destdir ""
 set mandir ""
 set vfs 0
+set userinstall 1
 
-
-for { set i 0 } { $i < [llength $argv] } { incr i } {
-set arg [lindex $argv $i]
- if { $arg == "-quiet" } {
-	set quiet 1
- } elseif { $arg == "-debian" } {
-	set debian 1
-	set quiet 1
-	incr i
-	set destdir [lindex $argv $i]
-
- } elseif { $arg == "-system" } {
- 	set system 1
- 	set quiet 1
- } elseif { $arg == "-vfs" } {
+set usage "install.tcl ?-quiet? ?-debian path|-system|-vfs?"
+set skipnext 0
+foreach arg $argv {
+ if {$skipnext} {set skipnext 0 
+ 				 continue
+				}
+ switch -- $arg {
+ 	"-quiet" {
+		set quiet 1
+		}
+	"-debian" {
+	    set debian 1
+    	set quiet 1
+	set userinstall 0
+	    set destdir [lindex $argv $i]
+		set skipnext 1	
+		}
+    "-system"  {
+    	set system 1
+	set userinstall 0
+    	set quiet 1
+		}
+    "-vfs" {
         set vfs 1
         set quiet 1
- } else {
- 	error "Unknown argument $arg"
-} 	
+	set userinstall 0
+	}
+	default {
+		return -code error "Unknown option \"$arg\"\n $usage"
+	}
+ }   
 }
 
 
@@ -196,7 +233,8 @@ set wishexec [info nameofexecutable]
  set docdir "$instroot/doc/taglog"
  set mandir "$instroot/man"
  set rootdir "~/diary"
-set taglogbin $bindir/taglog
+ set activitiesdir "$libdir"
+ set taglogbin $bindir/taglog
   } elseif { $debian } {
   set libdir "$destdir/usr/share/taglog"
   set bindir "$destdir/usr/bin"
@@ -204,12 +242,14 @@ set taglogbin $bindir/taglog
   set mandir "$destdir/usr/share/man"
   set taglogbin $destdir/usr/bin/taglog
   set rootdir "~/diary"
+  set activitiesdir "$libdir"
   } elseif { $vfs } {
   set destdir taglog.vfs
   set libdir "$destdir"
   set bindir "$destdir"
   set docdir ""
   set mandir ""
+  set activitiesdir "$libdir"
   set taglogbin "$destdir/main.tcl" 
 
   } else {
@@ -222,6 +262,7 @@ set docdir "~/bin"
 set mandir "~/bin"
 set taglogbin $bindir/taglog
 set rootdir "~/diary"
+set activitiesdir "$rootdir"
 }
 
 } elseif { $tcl_platform(platform) == "windows" } {
@@ -231,16 +272,21 @@ set bindir $libdir
 set docdir $libdir
 set mandir $libdir
 set rootdir $libdir
+set activitiesdir $rootdir
 set taglogbin $bindir/taglog.tcl
 
 } else {
  error "Unknown platform $tcl_platform(platform) - cant automatically install"
 }
 
+# Languages, other than English, supported
+#  Each must have a taglog_help_xx.tag and an xx.msg file
+set languages { de fr nl }
+
 set libfiles { tag.tcl taglog_action.tcl taglog_report.tcl taglog_init.tcl smtp.tcl taglog_help.tcl taglog_contact.tcl taglog_util.tcl taglog_project.tcl cal2.xbm logEdit.tcl taglog_widgets.tcl mainwin.tcl taglog_stack.tcl }
 set binfiles { taglog }
-set helpfiles { taglog_help_en.tag taglog_help_de.tag }
-set msgfiles { de.msg }
+set helpfiles { taglog_help_en.tag taglog_help_de.tag taglog_help_fr.tag taglog_help_nl.tag }
+set msgfiles { de.msg fr.msg nl.msg }
 set man1files { taglog.1 }
 set man3files { tag.3 }
 set activitiesfile {activities}
