@@ -21,22 +21,8 @@ set actin_f_a($winnum,$field) [string trim [$w.m.c.f.$safe_label.tagvalue get 1.
 
 }
 
-if { $actin_f_a($winnum,Id) == "*Auto*" } {
- if { $id_prefix != "" } {
- set id_prefix_tmp "$id_prefix."
-  } else {
-  set id_prefix_tmp ""
-  }
-set thisproject $actin_f_a($winnum,Project)
- if { $thisproject != "" } {
- set projseq [incprojactindex $thisproject]
- regsub -all " " $thisproject _ actin_f_a($winnum,Id)
- set actin_f_a($winnum,Id) "$id_prefix_tmp$actin_f_a($winnum,Id).$projseq" 
 
- } else {
- set actin_f_a($winnum,Id) "${id_prefix_tmp}taglog.$year$month$day$hh$mm"
- }
-}
+setupAutoId $winnum
  
 set thisaction [writeaction $thisaction $winnum]
 setactionsmenu
@@ -115,7 +101,7 @@ destroy $w
 
 }
 
-proc actionInputWindow { mode {winnum 0} {idvar ""} } {
+proc actionInputWindow { mode {winnum 0} {idvar ""} {setValues ""} } {
 global actin_f_a
 global hh mm ss year month day
 global validStates
@@ -123,6 +109,8 @@ global scrollside
 global allcontacts
 global currentProject
 
+
+
 set actin_filled_fields {}
 set actin_empty_fields {}
 
@@ -135,6 +123,20 @@ global actin_f_a
 upvar actin_filled_fields filled_fields
 upvar actin_emtpy_fields empty_fields
 
+upvar setValues setVals 
+
+if { $setVals != "" } {
+ # setVals is a list of variable names and values
+ foreach zz $setVals {
+  if {[lindex $zz 0] == $label } {
+     set var_default [lindex $zz 1]
+#     puts "setting the default for $label to $var_default"
+     }
+  }
+}
+
+
+
 regsub -all {\.-} $label _ safe_label
 set safe_label [string tolower $safe_label]
 
@@ -326,16 +328,52 @@ button $w.bot.ok -text [mc Add] -command "actionInputOK $w $winnum $idvar"
 } elseif { $mode == "edit" } {
 button $w.bot.ok -text [mc "Edit"] -command "actionEditOK $w 0"
 }
+button $w.bot.subtask -text [mc "Add Subtask..."] -command "addSubtask $winnum"
 button $w.bot.mail -text "Mail..." -command "actionMail $w $winnum"
 button $w.bot.cancel -text [mc Cancel] -command "doCancel $w"
 button $w.bot.help -text [mc Help] -command "taghelp actinput"
-pack $w.bot.ok $w.bot.mail $w.bot.cancel $w.bot.help -in $w.bot -side left
+pack $w.bot.ok $w.bot.subtask $w.bot.mail $w.bot.cancel $w.bot.help -in $w.bot -side left
+
 pack $w.bot
 
 tkwait window $w
 
 }
 
+proc setupAutoId { winnum } {
+global actin_f_a
+
+if { $actin_f_a($winnum,Id) == "*Auto*" } {
+ if { $actin_f_a($winnum,Project) != "" } {
+ set projseq [incprojactindex $actin_f_a($winnum,Project)]
+ regsub -all " " $actin_f_a($winnum,Project) _ actin_f_a($winnum,Id)
+ set actin_f_a($winnum,Id) "$actin_f_a($winnum,Id).$projseq" 
+
+ } else {
+ set actin_f_a($winnum,Id) "taglog.$year$month$day$hh$mm"
+ }
+}
+
+}
+
+proc addSubtask { winnum } {
+global actin_f_a
+
+setupAutoId $winnum
+
+set parentProject $actin_f_a($winnum,Project)
+set parentActid $actin_f_a($winnum,Id)
+
+
+set newwinnum [incr winnum]
+set setV1 [list Project $parentProject]
+lappend setVals $setV1
+set setV1 [list Subtask-of $parentActid]
+lappend setVals $setV1
+actionInputWindow input $newwinnum "" $setVals
+
+}
+
 proc actionMailOK { actin_win winnum } {
 global actmail_to
 global year month day hh mm
@@ -350,17 +388,8 @@ set actin_f_a($winnum,Summary) [string trim [$actin_win.m.c.f.summary.tagvalue g
 
 set actmail_message [string trim [.actmail.message.body get 1.0 end]]
 
-if { $actin_f_a($winnum,Id) == "*Auto*" } {
- if { $actin_f_a($winnum,Project) != "" } {
- set projseq [incprojactindex $actin_f_a($winnum,Project)]
- regsub -all " " $actin_f_a($winnum,Project) _ actin_f_a($winnum,Id)
- set actin_f_a($winnum,Id) "$actin_f_a($winnum,Id).$projseq" 
+setupAutoId $winnum
 
- } else {
- set actin_f_a($winnum,Id) "taglog.$year$month$day$hh$mm"
- }
-}
- 
  set thisaction [getact_input_fields $winnum]
 
 if { $actmail_to != "" } {
@@ -1290,10 +1319,15 @@ set activeactions ""
 set test [list Status "-in" { Active } ]
 lappend tests $test
 getallact
-set actions [ tag extract $allact $tests ]
+#set actions [ tag extract $allact $tests ]
+set idx 0
+while { $idx != -1 } {
+set idx [tag find $allact $tests $idx]
+
+if { $idx != -1 } {
 
 # Now to extract the bits of info we need - 
-foreach entry $actions {
+ set entry [lindex $allact $idx]
  set thisproject ""
  set thispriority 50
  foreach item $entry {
@@ -1310,8 +1344,12 @@ foreach entry $actions {
  }
  }
 
- set thisentry [ list $thisid $thistitle $thisproject $thispriority]
+ set thisentry [ list $thisid $thistitle $thisproject $thispriority $idx]
+ incr idx
  lappend activeactions $thisentry
+}
+}
+
 
 if { [info tclversion] >=8.0 } {
 set activeactions [lsort -integer -index 3 $activeactions]
@@ -1320,6 +1358,47 @@ set activeactions [lsort -integer -index 3 $activeactions]
 }
 
 
+proc setactionsmenu {} {
+global activeactions num_today_actions allact
+getactiveactions
+ .actionbar.action.m delete 1 end
+.actionbar.action.m add command -label "--" \
+	-command "setcurrentAction -1"
+for { set i 0 } {$i < [llength $activeactions]} {incr i} {
+ # hide subtasks from top level
+ if { [tag_entryVal [lindex $allact [lindex [lindex $activeactions $i] 4]] Subtask-of] != "" } {
+    continue
+   }  
+ .actionbar.action.m add command -label [lindex [ lindex $activeactions $i ] 1] \
+	-command "setcurrentAction \"[lindex [lindex $activeactions $i ] 0]\""
+# if it had subtasks the add them. (note that this bit should really be
+# recursive
+ if { [tag_entryVal [lindex $allact [lindex [lindex $activeactions $i] 4]] Subtasks] != "" } {
+   set submenu .actionbar.action.m.s$i
+   .actionbar.action.m add cascade -label "[lindex [ lindex $activeactions $i ] 1]..." -menu $submenu
+   if {[winfo exists $submenu]} {
+	$submenu delete 1 end
+        } else {
+	menu $submenu
+	}
+    set subacts [split [tag_entryVal [lindex $allact [lindex [lindex $activeactions $i] 4]] Subtasks] ","] 
+    foreach subact $subacts { 
+     # We are only interested in active subactions, which must be in activeactions
+      for { set j 0 } {$j < [llength $activeactions]} {incr j} {
+       if {[lindex [lindex $activeactions $j ] 0]==$subact } { 
+     $submenu add command -label "[lindex [lindex $activeactions $j ] 1]" \
+	-command "setcurrentAction \"[lindex [lindex $activeactions $j ] 0]\""
+          }
+       }
+     }
+   }
+}
+
+for { set i 1 } { $i <= $num_today_actions } { incr i } {
+ menu_create .actions.a$i.id [mc Action]$i actreminder 0 actAct menu_setText .actions.a$i.title
+ }
+
+
 }
 
 proc setcurrentAction { id } {
@@ -1785,3 +1864,69 @@ set allact $newacts
 set allactstate modified
 writeallact
 }
+
+proc Update_subtasks { actionid {subtaskid ""} } {
+global allact allactstate
+# Update the subtask field for actionid
+# - If a subtask Id is specified then only that subtask is added to the
+# subtasks for that action - otherwise all actions are checked to see if they
+# are subtasks of the action.
+
+
+if { $actionid == "" } {
+  error "Update_subtasks called with null actionid"
+  return
+  }
+
+if { $subtaskid == "" } {
+
+ set si 0
+ while { $si != -1} {
+   set si [tag findval $allact Subtask-of $actionid $si ]
+   if { $si != -1 } {
+     Update_subtasks $actionid [tag_entryVal [lindex $allact $si] Id]
+     incr si
+     }
+  }
+
+} else {
+ # check if the subtaskid already appears in the subtasks field for the action
+ set idx [tag findval $allact Id $actionid]
+ if { $idx == -1 } {
+   error "Update_subtasks called for non-existant action $actionid"
+   return }
+
+  set entry [lindex $allact $idx]
+  set subtasks [tag_entryVal $entry Subtasks ]
+  if { [string first $subtaskid $subtasks] != -1 } { return }
+  if {$subtasks == "" } {
+	set subtasks $subtaskid
+	} else {
+  	set subtasks "$subtasks,$subtaskid"
+	}
+
+  if { $subtasks != "" } {
+  tag setorreplace entry Subtasks $subtasks 
+
+  set allact [lreplace $allact $idx $idx $entry]
+  set allactstate modified
+  }
+writeallact
+}
+
+}
+
+proc Update_all_subtasks {} {
+# Find all actions which have subtasks and call Update_subtasks on them.
+# I think I need to work through all actions.
+
+global allact
+
+foreach action $allact {
+ set id [tag_entryVal $action Id]
+ if { $id != "" } { Update_subtasks [tag_entryVal $action Id] }
+} 
+
+
+}
+
