@@ -48,6 +48,7 @@ global stackdepth stack_info
 global projects_url
 global log_summary
 global activitiesfilename
+global debug
 # Initialise common variables
 
 
@@ -114,6 +115,8 @@ set action_textarea_fields { Description Deliverable Reason Summary}
 set dateformat_view "YYYY-MM-DD"
 set dateformat_tcl "%Y-%m-%d"
 
+set debug 0
+
 set rootdir "~/diary"
 if { $tcl_platform(platform) == "windows" } {
  if [ info exists env(USERPROFILE)] {
@@ -147,7 +150,7 @@ set activities { phone-in phone-out meeting meeting-preparation meeting-review e
 
 
 set showtime_format 1
-set showtime_spreadoverheads 1
+set showtime_spreadoverheads byweek
 set showtime_bookbycode 0
 set showtime_hours_per_day 7.58
 set timebook_startlastweek 1
@@ -181,6 +184,8 @@ if { [ file readable $scriptdir/taglog_help_en.tag] } {
   set helpdir ~/lib/taglog
   } elseif { [file readable /usr/lib/taglog/taglog_help_en.tag] } {
   set helpdir /usr/lib/taglog
+  } elseif { [file readable /usr/local/lib/taglog/taglog_help_en.tag] } {
+  set helpdir /usr/local/lib/taglog
   } elseif { [file readable /usr/share/taglog/taglog_help_en.tag] } {
   set helpdir /usr/share/taglog
   } elseif {  [ file readable /usr/share/doc/taglog/taglog_help_en.tag] } {
@@ -355,10 +360,12 @@ global projects_url editprefs_projects_url
 global editprefs_activitiesFile
 global activities
 global activitiesfilename
+global libsdir editprefs_libsdir
 
 set activitiesfilename $editprefs_activitiesFile
 set docdir $editprefs_docdir
 set rootdir $editprefs_rootdir
+set libsdir $editprefs_libsdir
 # set helpdir $editprefs_helpdir
 set language $editprefs_language
 if { ( $showtime_hours_per_day < 24 ) && ( $editprefs_showtime_hours_per_day > 0) } {
@@ -423,7 +430,7 @@ destroy .editprefs
 proc editPrefs {} {
 global tcl_platform env
 global docdir language editprefs_docdir editprefs_language
-global rootdir editprefs_rootdir
+global rootdir editprefs_rootdir libsdir editprefs_libsdir
 global editprefs_showtime_hours_per_day showtime_hours_per_day
 global editprefs_showtime_spreadoverheads showtime_spreadoverheads
 global editprefs_timebook_startlastweek timebook_startlastweek
@@ -455,6 +462,15 @@ entry .editprefs.docdir.v -textvariable editprefs_docdir -width 30
 pack .editprefs.docdir.l .editprefs.docdir.v -side left -in .editprefs.docdir
 pack .editprefs.docdir
 
+set editprefs_libsdir $libsdir
+frame .editprefs.libsdir
+menubutton .editprefs.libsdir.l -text [mc "Library Directory"] -menu .editprefs.libsdir.l.m
+menu .editprefs.libsdir.l.m
+.editprefs.libsdir.l.m add command -label [mc Help] -command "taghelp prefs_libsdir"
+entry .editprefs.libsdir.v -textvariable editprefs_libsdir -width 30
+pack .editprefs.libsdir.l .editprefs.libsdir.v -side left -in .editprefs.libsdir
+pack .editprefs.libsdir
+
 set editprefs_rootdir $rootdir
 frame .editprefs.rootdir
 menubutton .editprefs.rootdir.l -text [mc "Data directory root"] -menu .editprefs.rootdir.l.m
@@ -535,7 +551,10 @@ frame .editprefs.spreadoverheads
 menubutton .editprefs.spreadoverheads.l -text [mc "Spread Overheads"] -menu .editprefs.spreadoverheads.l.m
 menu .editprefs.spreadoverheads.l.m
 .editprefs.spreadoverheads.l.m add command -label [mc Help] -command "taghelp prefs_showtime_spreadoverheads"
-checkbutton .editprefs.spreadoverheads.e -relief flat -variable showtime_spreadoverheads
+radiobutton .editprefs.spreadoverheads.off -relief flat -variable showtime_spreadoverheads -value off -text [mc Off]
+radiobutton .editprefs.spreadoverheads.byday -relief flat -variable showtime_spreadoverheads -value byday -text [mc Day]
+radiobutton .editprefs.spreadoverheads.byweek -relief flat -variable showtime_spreadoverheads -value byweek -text [mc Week]
+
 # Put the Default time bookings report starts last week flag here too
 set editprefs_timebook_startlastweek $timebook_startlastweek
 menubutton .editprefs.spreadoverheads.l2 -text [mc "Time Bookings starts"] -menu .editprefs.spreadoverheads.l2.m
@@ -544,7 +563,7 @@ menu .editprefs.spreadoverheads.l2.m
 radiobutton .editprefs.spreadoverheads.r1 -text [mc "last week"] -variable editprefs_timebook_startlastweek -value 1
 radiobutton .editprefs.spreadoverheads.r2 -text [mc "this week"] -variable editprefs_timebook_startlastweek -value 0
 
-pack .editprefs.spreadoverheads.l .editprefs.spreadoverheads.e .editprefs.spreadoverheads.l2 .editprefs.spreadoverheads.r1 .editprefs.spreadoverheads.l2 .editprefs.spreadoverheads.r1 .editprefs.spreadoverheads.r2 -in .editprefs.spreadoverheads -side left
+pack .editprefs.spreadoverheads.l .editprefs.spreadoverheads.off .editprefs.spreadoverheads.byday .editprefs.spreadoverheads.byweek .editprefs.spreadoverheads.l2 .editprefs.spreadoverheads.r1 .editprefs.spreadoverheads.l2 .editprefs.spreadoverheads.r1 .editprefs.spreadoverheads.r2 -in .editprefs.spreadoverheads -side left
 pack .editprefs.spreadoverheads
 
 
@@ -554,7 +573,7 @@ frame .editprefs.hours
 menubutton .editprefs.hours.l -text [mc "Hours Worked per Day (decimal)"] -menu .editprefs.hours.l.m
 menu .editprefs.hours.l.m
 .editprefs.hours.l.m add command -label [mc Help] -command "taghelp prefs_showtime_hours_per_day"
-entry .editprefs.hours.e -textvariable editprefs_showtime_hours_per_day
+entry .editprefs.hours.e -textvariable editprefs_showtime_hours_per_day -width 6
 pack .editprefs.hours.l .editprefs.hours.e -side left -in .editprefs.hours
 pack .editprefs.hours
 
@@ -705,7 +724,7 @@ global docdir
 global language
 global showtime_hours_per_day
 global dateformat_view dateformat_tcl
-global rootdir
+global rootdir libsdir
 global num_today_actions history_win_depth current_win_depth
 global id_prefix
 global start_procs exit_procs
@@ -737,6 +756,7 @@ if { $prefsfile !="" } {
  puts $f "set language $language"
  puts $f "set showtime_hours_per_day $showtime_hours_per_day"
  puts $f "set docdir \"$docdir\""
+ puts $f "set libsdir \"$libsdir\""
  puts $f "set rootdir \"$rootdir\""
  puts $f "set showtime_spreadoverheads $showtime_spreadoverheads"
  puts $f "set timebook_startlastweek $timebook_startlastweek"
