@@ -835,4 +835,132 @@ unset update_projects_allproj
 
 }
 
+proc doArchiveProjects {} {
+global archiveProjectCloseDate archiveProjectCheckActions archiveProjectFile
+global rootdir
+
+toplevel .archiveProject
+wm title .archiveProject [mc "Archive old projects"]
+
+frame .archiveProject.closedate
+menubutton .archiveProject.closedate.l -text [mc "Archive projects closed before"] -menu .archiveProject.closedate.l.m
+menu .archiveProject.closedate.l.m
+set todayiso [clock format [clock seconds ] -format "%Y-%m-%d"]
+set todaydisp [dateiso2disp $todayiso]
+.archiveProject.closedate.l.m add command -label "[mc Today] ($todaydisp)" -command "set archiveProjectCloseDate $todayiso"
+pack .archiveProject.closedate.l -side left -fill x
+calUtil_win .archiveProject.closedate.d "" archiveProjectCloseDate
+pack .archiveProject.closedate.d
+.archiveProject.closedate.l.m add separator
+.archiveProject.closedate.l.m add command -label [mc Help] -command "taghelp archproj_closedate"
+entry .archiveProject.closedate.v -width 10 -textvariable archiveProjectCloseDate
+pack .archiveProject.closedate.l -side left -fill x
+pack .archiveProject.closedate
+
+set archiveProjectFile "$rootdir/projects-archive-$todayiso.tag"
+frame .archiveProject.filename
+menubutton .archiveProject.filename.l -text [mc "Archive projects to filename"] -menu .archiveProject.filename.l.m
+menu .archiveProject.filename.l.m
+
+entry .archiveProject.filename.v -width 20 -textvariable archiveProjectFile
+pack .archiveProject.filename.l .archiveProject.filename.v -side left -fill x
+pack .archiveProject.filename
+
+
+set archiveProjectCheckActions 1
+frame .archiveProject.checkActions
+checkbutton .archiveProject.checkActions.c -text [mc "Do not archive projects with active or pending actions"] -variable archiveProjectCheckActions
+pack .archiveProject.checkActions.c
+pack .archiveProject.checkActions
+
+
+frame .archiveProject.file
+# set up the archive file name here - with a widget ?
+
+frame .archiveProject.bot
+button .archiveProject.bot.ok -text OK -command {doArchiveProjectsOK}
+button .archiveProject.bot.cancel -text [mc Cancel] -command {destroy .archiveProject}
+button .archiveProject.bot.help -text [mc Help] -command "taghelp archiveproject"
+pack .archiveProject.bot.ok .archiveProject.bot.cancel .archiveProject.bot.help -side left -in .archiveProject.bot
+pack .archiveProject.bot
+
+tkwait window .archiveProject
+
+}
+
+
+proc doArchiveProjectsOK {} {
+global archiveProjectCloseDate archiveProjectCheckActions archiveProjectFile
+global allproj allact
+
+set needMessageBox 0
+
+# Find all the projects which closed before the close date
+
+set tests ""
+set test [list EndDate -earlier $archiveProjectCloseDate]
+lappend tests $test
+
+set archiveProjects [lrange $allproj 1 end]
+set archiveProjects [tag extract $archiveProjects $tests]
+
+if { $archiveProjectCheckActions } {
+
+foreach action $allact {
+# check to see if if is active or pending, then check to see if the project
+# is in the archiveProjects. If it is then remove it.
+
+ set st [tag_entryVal $action Status]
+
+ if { $st == "Pending"  ||  $st == "Active" } {
+   set prj [tag_entryVal $action Project]
+
+  # Find out if that project is in our list of Projects to archive.
+
+  set i -1
+  foreach tproj $archiveProjects {
+  incr i
+    if { [tag_entryVal $tproj Name] == $prj } {
+      if { ! $needMessageBox } {
+        set needMessageBox 1
+        set messages ""
+        }
+      set messages "$messages Project $prj removed from archive list as it has Pending or Active actions\n"
+      set archiveProjects [lreplace $archiveProjects $i $i]
+      break
+    }
+  }
+   }
+}
+}
+
+if { $needMessageBox } {
+
+tk_messageBox -title [mc "Archive projects notifications"] -message $messages
+}
+
+
+tag writefile $archiveProjectFile $archiveProjects
+
+# remove all the projects which were in archiveProjects from allproj
+
+set i -1
+foreach proj $allproj {
+ incr i
+ set pn [tag_entryVal $proj Name]
+
+  foreach tproj $archiveProjects {
+     if { [tag_entryVal $tproj Name] == $pn } {
+       set allproj [lreplace $allproj $i $i]
+       incr i -1
+       break
+       }
+
+ }
+
+}
+  
+writeprojects
+
+}
 
