@@ -421,13 +421,9 @@ close $f
 proc firstDayOfWeek { weekno year } {
 # returns the day number of the first day of week weekno for a particular year
 
-# what day of the week is the first
 set firstday [clock format [clock scan "1 jan $year"] -format "%w"]
-# puts "first day is $firstday"
 if { $firstday <= 4 } { incr firstday 7 }
-#set offset [expr { ( 8- $firstday ) %7 } ]
 set offset [expr { 1- $firstday } ]
-# puts "offset is $offset"
 
 return [expr { $weekno*7 + $offset }]
 }
@@ -437,9 +433,61 @@ proc showTimeBookings {} {
 global timebook_year timebook_weekno rootdir showtime_format showtime_spreadoverheads showtime_bookbycode timebook_numweeks
 global GL_tableFont
 
+proc getProjectTimes { filename timearray booked_proj } {
+# return an array with the project times used during that day.
+# Note that timearray is the name of the array.
+# The array indices are the real projects used,
+
+upvar $timearray daytimes
+upvar $booked_proj booked_projects
+
+  set logs [ tag readfile $filename ]
+  set logs [ lrange $logs 1 end ]
+  set thisproject unknown
+
+ foreach entry $logs {
+  set starttime 0
+  set endtime 0
+  foreach item $entry {
+   set tagname [lindex $item 0]
+   set tagvalue [lindex $item 1]
+   if { $tagname == "End" } {
+  # Because this is the end tag we should have all the values we are going
+  # to get
+  set duration [timediff $starttime $endtime]
+
+  # add the project to booked_projects if we have not seen it before
+  if { [lsearch -exact $booked_projects $thisproject ] == -1 } {
+	lappend booked_projects $thisproject
+##	set projtotals($displayname) "00:00"
+    }
+
+ inctime daytimes($thisproject) $duration
+
+ set thisproject unknown
+  } elseif { $tagname == "StartTime" } {
+   set starttime $tagvalue
+  } elseif { $tagname == "EndTime" } {
+   set endtime $tagvalue
+  } elseif { $tagname == "Project" } {
+    set thisproject $tagvalue
+  } else {
+ }
+}  
+
+}
+
+}
+
+
+
 toplevel .timebook
 wm title .timebook [mc "Time Bookings"]
 
+#######
+set newway 0
+if { $showtime_spreadoverheads == "byday" } { set newway 1 }
+
 # We wont display errors unless we have to
 set display_errors 0
 frame .timebook.errors
@@ -522,6 +570,113 @@ unset projtimes${day}
  set filename1  [ clock format [clock scan "1 jan $timebook_year $day days"] -format "%m%d"]
  set filename "$rootdir/log$timebook_year/$filename1.tag"
  if [file exists $filename] {
+
+ if { $newway } {
+###
+# for testing
+# Clear the thisnames array
+  set thisday(empty) "00:00"
+  foreach el [array names thisday] { unset thisday($el) }
+  getProjectTimes $filename thisday booked_projects
+ 
+  puts "thisday is $day"
+  foreach el [array names thisday] {
+    puts "thisday($el) = $thisday($el)"
+  }
+ 
+# Process thisday array to roll discovered totals into the week totals, also
+# spread overheads by day if required.
+
+ foreach el [array names thisday] {
+
+   set duration [timediff "00:00:00" $thisday($el)]
+   if { [isbreak $el ]} {
+       inctime breakstotal $duration
+     } else {
+	inctime nonbreakstotal $duration
+	inctime daytotal($day) $duration
+     }
+   if { [isimmutable $el] } {
+      inctime immutabletotal $duration
+      inctime dayimmutable($day) $duration
+      }
+   if { [isoverhead $el] } {
+      inctime dayoverheads($day) $duration
+      inctime totaloverheads $duration
+      }
+   
+
+ }
+
+# Having been through the whole day - spread overheads by day if required.
+
+if { $showtime_spreadoverheads == "byday" } {
+ if { [info exist dayoverheads($day) ] } {
+ if { $dayoverheads($day) != "00:00:00" } {
+  set secstospread [timediff "00:00:00" $dayoverheads($day)]
+  puts "we have overheads on $day of $dayoverheads($day) = $secstospread secs"
+  set totalsecs [timediff "00:00" $daytotal($day)]
+  set immutablesecs [timediff "00:00" dayimmutable($day)]
+  set totalsecs [expr { $totalsecs - $immutablesecs - $secstospread } ]
+  puts "we have $totalsecs seconds of todays projects"
+  puts "which are [array names thisday]"  
+
+  foreach pr [array names thisday] {
+#   puts "looking at project $pr"
+   if { [isoverhead $pr] || [isimmutable $pr] || [isbreak $pr ] } {
+#     puts "ignore $pr"
+   } else {
+    set projsecs [timediff "00:00:00" $thisday($pr)]
+    set projfraction [expr ($projsecs * 1.0) / $totalsecs]
+    puts "Time for $pr was $thisday($pr) - $projsecs - fraction is $projfraction"
+    set extratime [ expr { round($projfraction * $secstospread)} ]
+    inctime thisday($pr) $extratime
+    puts "Add $extratime seconds to $pr - now $thisday($pr)"
+
+# Now convert projects to displayed names, or codes - note that this might
+# compress several projects with the same code into one entry
+
+# Deal with different ways to set up the project
+ if { $showtime_bookbycode == 0 } {
+ set displayname [getprojcode $pr]
+ } elseif { $showtime_bookbycode == 1 } {
+ set displayname $pr
+ } elseif { $showtime_bookbycode == 2 } {
+ set displayname [getprojcode $pr]
+ set displayname "$displayname ($pr)"
+ } else {
+    error "showtime_bookbycode has invalid value $showtime_bookbycode"
+ }
+
+  # add the project to booked_projects if we have not seen it before
+  if { [lsearch -exact $booked_projects $displayname ] == -1 } {
+	lappend booked_projects $pr
+	set projtotals($displayname) "00:00"
+    }
+
+ inctime projtimes${day}($displayname) $duration
+ inctime projtotals($displayname) $duration
+   }
+  }
+ # end of foreach pr
+
+
+  }
+
+}
+
+}
+  # End of if showtime_spreadoverheads == byday
+
+
+
+
+
+
+ } else {
+# Oldway
+
+
   set logs [ tag readfile $filename ]
   set logs [ lrange $logs 1 end ]
   set thisproject unknown
@@ -553,7 +708,7 @@ unset projtimes${day}
 # Is is a breaks project ?
   if { [isbreak $thisproject ] } { 
    inctime breakstotal $duration
-  } elseif { ( $showtime_spreadoverheads) && ( [isoverhead $thisproject]) } {
+  } elseif { ( $showtime_spreadoverheads != "off") && ( [isoverhead $thisproject]) } {
 
  inctime daytotal($day) $duration
  inctime nonbreakstotal $duration
@@ -592,6 +747,10 @@ unset projtimes${day}
 }
 
 
+}
+# end of oldway
+
+
 
  } else {
    # want to warn if we cant open the file (unless it is Sat or Sun)
@@ -606,7 +765,7 @@ unset projtimes${day}
 
 }
 
-if { $showtime_spreadoverheads } {
+if { $showtime_spreadoverheads == "byweek" } {
 #puts "Total of overheads is $total_overheads"
 # Work through the days, adjusting the times for the non-overheads projects,
 # so as to keep the total constant,
@@ -652,6 +811,8 @@ if { $day < [expr {$startday+6}]} {
 }
 .timebook.main.body insert end "\n\n" bodydata
 
+
+
 # work through the booked projects
 foreach thisproject $booked_projects {
 # puts "project is $thisproject Total time is $projtotals($thisproject)"
@@ -661,10 +822,11 @@ set displayproj [string range $thisproject 0 18]
 .timebook.main.body insert end "$displayproj\t" bodydata
 
 for { set day $startday } {$day < [expr {$startday+7}]} { incr day } {
-if { $showtime_spreadoverheads && [ info exists dayoverheads($day)]  } {
+if { ($showtime_spreadoverheads == "byweek") && [ info exists dayoverheads($day)]  } {
  if { ! [isimmutable $thisproject]} {
 # redistribute the spare minutes (or seconds now that we work in them)
  set secstospread [timediff "00:00"  $dayoverheads($day)]
+
  set secsthisproj [ expr { round( $secstospread * $projfraction($thisproject))}]
 # puts "We have  $dayoverheads($day) = $minstospread minutes to spread _ $minsthisproj"
  inctime projtimes${day}($thisproject) $secsthisproj
@@ -729,9 +891,19 @@ radiobutton .timebooksel.top.decimaldays -text [mc "Decimal days"] -relief flat
 pack .timebooksel.top.label .timebooksel.top.hhmm .timebooksel.top.decimalhours .timebooksel.top.decimaldays -side left -in .timebooksel.top
 pack .timebooksel.top
 
-frame .timebooksel.t1
-checkbutton .timebooksel.t1.spread_overheads -text [mc "Spread overhead projects"] -relief flat -variable showtime_spreadoverheads
-pack .timebooksel.t1.spread_overheads .timebooksel.t1
+if { $showtime_spreadoverheads == 0 } { set showtime_spreadoverheads off }
+if { $showtime_spreadoverheads == 1 } { set showtime_spreadoverheads byweek }
+
+
+frame .timebooksel.spread_overheads
+menubutton .timebooksel.spread_overheads.l -text [mc "Spread overhead projects"] -menu .timebooksel.spread_overheads.l.m
+menu .timebooksel.spread_overheads.l.m
+.timebooksel.spread_overheads.l.m add command -label [mc Help] -command "taghelp timebooksel_spreadoverheads"
+radiobutton .timebooksel.spread_overheads.off -variable showtime_spreadoverheads -value off -text [mc Off]
+radiobutton .timebooksel.spread_overheads.byday -variable showtime_spreadoverheads -value byday -text [mc Day] -state disabled
+radiobutton .timebooksel.spread_overheads.byweek -variable showtime_spreadoverheads -value byweek -text [mc Week]
+pack .timebooksel.spread_overheads.l .timebooksel.spread_overheads.off .timebooksel.spread_overheads.byday .timebooksel.spread_overheads.byweek -in .timebooksel.spread_overheads -side left
+pack .timebooksel.spread_overheads
 frame .timebooksel.t2
 label .timebooksel.t2.bookas -text [mc "Book by Project"]
 radiobutton .timebooksel.t2.bookcode -text "Code" -relief flat -variable showtime_bookbycode -value 0
