@@ -49,6 +49,17 @@ proc timediff { start end } {
 
 }
 
+######## dateiso2disp
+#  convert an ISO date into the current display format
+#
+# Arguments:
+#   date - the date, in internal format, to be displayed
+#
+# Results:
+#   returns a string containing the date in the format specified
+#    by the global variable dateformat_view
+#
+
 proc dateiso2disp { date } {
 global dateformat_view
 
@@ -67,6 +78,10 @@ if { $dateformat_view == "DD/MM/YYYY" } {
 
 }
 
+
+# datedisp2iso
+
+
 proc datedisp2iso { date }  {
 global dateformat_view
 
@@ -96,12 +111,12 @@ return $result
 
 }
 # ---------------------- taglog_getList ---------------------------------
-# provides a simple list extracted from a complex list stroed in a global
+# provides a simple list extracted from a complex list stored in a global
 # variable
 #
 # lType	switch for the list to create
-#	projAll	provide all project names from list in global variable projects
-#	proj	provide project names from list in global variable projects,
+#	projAll	provide all project names from list in global variable allproj
+#	proj	provide project names from list in global variable allproj,
 #		which are not closed
 #	actAct	provide actions from the list in global variable activeactions
 #	acties	provide activities from the list in global variable activities
@@ -110,38 +125,43 @@ return $result
 #
 # return:	output list or ""
 proc taglog_getList {lType} {
-   global projects
    global activeactions
    global activities
    global allcontacts
+   global allproj
 
    switch $lType {
       projAll {
       # all projects
-         foreach i $projects {
-            lappend iList [lindex $i 0]
-         }
+#         foreach i $projects {
+#            lappend iList [lindex $i 0]
+#         }
+          foreach proj $allproj {
+	     lappend iList [tag_entryVal $proj Name]
+	  }
       }
       proj {
       # projects which are not closed
 
       # now we return the active projects first by making two passes
       # through the projects list
-         foreach i $projects {
-            if { (![projclosed [lindex $i 0]]) && ( [isactive [lindex $i 0]])} {
-               lappend iList [lindex $i 0]
+         foreach proj $allproj {
+	    set pname [tag_entryVal $proj Name]
+            if { (![projclosed $pname]) && ( [isactive $pname])} {
+               lappend iList $pname
                }    
          }
-         foreach i $projects {
-	    if { (![projclosed [lindex $i 0]]) && ( ![isactive [lindex $i 0]])} {
-               lappend iList [lindex $i 0]
+         foreach proj $allproj {
+            set pname [tag_entryVal $proj Name]
+	    if { (![projclosed $pname]) && ( ![isactive $pname])} {
+               lappend iList $pname 
 	    }
          }
       }
       cont {
       # contacts
          foreach i $allcontacts {
-            set val [logEdit_tagVal $i Id]
+            set val [tag_entryVal $i Id]
 	    if {$val != ""} {
                lappend iList $val
 	    }
